// (C) 2019-2025 GoodData Corporation
import { NotSupported, } from "@gooddata/sdk-backend-spi";
/**
 * This implementation of auth provider ensures, that the auth provider is called exactly once in the happy path
 * execution where provider successfully authenticates a principal.
 *
 * If underlying provider fails, subsequent calls that need authentication will land in the provider.
 *
 * This class encapsulates the stateful nature of interaction of the provider across multiple different instances
 * of the bear backend, all of which are set with the same provider. All instances of the backend should be
 * subject to the same authentication flow AND the call to the authentication provider should be synchronized
 * through this scoped instance.
 *
 * @internal
 */
export class AuthProviderCallGuard {
    realProvider;
    inflightRequest;
    principal;
    disablePrincipalCache;
    constructor(realProvider) {
        this.realProvider = realProvider;
        this.disablePrincipalCache = realProvider.disablePrincipalCache;
    }
    reset = () => {
        this.principal = undefined;
    };
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    initializeClient = (client) => {
        this.realProvider.initializeClient?.(client);
    };
    onNotAuthenticated = (context, error) => {
        this.realProvider.onNotAuthenticated?.(context, error);
    };
    authenticate = (context) => {
        if (this.principal && !this.disablePrincipalCache) {
            return Promise.resolve(this.principal);
        }
        if (this.inflightRequest) {
            return this.inflightRequest;
        }
        this.inflightRequest = this.realProvider
            .authenticate(context)
            .then((res) => {
            this.principal = this.disablePrincipalCache ? undefined : res;
            this.inflightRequest = undefined;
            return res;
        })
            .catch((err) => {
            this.inflightRequest = undefined;
            throw err;
        });
        return this.inflightRequest;
    };
    getCurrentPrincipal(context) {
        return this.realProvider.getCurrentPrincipal(context);
    }
    async deauthenticate(context, returnTo) {
        return this.realProvider.deauthenticate(context, returnTo);
    }
}
/**
 * This implementation serves as a Null object for IAuthProviderCallGuard.
 *
 * @internal
 */
export class NoopAuthProvider {
    disablePrincipalCache = false;
    authenticate(_context) {
        throw new NotSupported("NoopAuthProvider does not support authenticate");
    }
    getCurrentPrincipal(_context) {
        throw new NotSupported("NoopAuthProvider does not support getCurrentPrincipal");
    }
    deauthenticate(_context) {
        throw new NotSupported("NoopAuthProvider does not support deauthenticate");
    }
    reset() {
        throw new NotSupported("NoopAuthProvider does not support reset");
    }
}
export const AnonymousUser = {
    userId: "anonymous",
};
/**
 * This is a noop implementation of authentication provider - it does nothing and assumes anonymous user.
 *
 * @public
 */
export class AnonymousAuthProvider {
    disablePrincipalCache = false;
    authenticate(_context) {
        return Promise.resolve(AnonymousUser);
    }
    getCurrentPrincipal(_context) {
        return Promise.resolve(AnonymousUser);
    }
    deauthenticate(_context) {
        return Promise.resolve();
    }
    reset() {
        return;
    }
}
//# sourceMappingURL=auth.js.map